@@ -6,8 +6,8 @@
 #'
 #' @section Note:
 #' If a needed class of model is not supported by
-#' [car::Anova], please create an
-#' [issue](https://github.com/ddsjoberg/gtsummary/issues) to request support.
+#' [car::Anova], please create a
+#' [GitHub Issue](https://github.com/ddsjoberg/gtsummary/issues) to request support.
 #'
 #' @param x `tbl_regression` or `tbl_uvregression` object
 #' @param ... Further arguments passed to or from other methods.
@@ -34,17 +34,20 @@ add_global_p <- function(x, ...) {
 #'
 #' @section Note:
 #' If a needed class of model is not supported by
-#' [car::Anova], please create an
-#' [issue](https://github.com/ddsjoberg/gtsummary/issues) to request support.
+#' [car::Anova], please create a
+#' [GitHub Issue](https://github.com/ddsjoberg/gtsummary/issues) to request support.
 #'
 #'
 #' @param x Object with class `tbl_regression` from the
 #' [tbl_regression] function
-#' @param terms Character vector of terms for which to add global p-values.  Default
-#' is `NULL` which will add global p-values for all categorical variables
 #' @param keep Logical argument indicating whether to also retain the individual
 #' p-values in the table output for each level of the categorical variable.
 #' Default is `FALSE`
+#' @param include Variables to calculate global p-value for. Input may be a vector of
+#' quoted or unquoted variable names. tidyselect and gtsummary select helper
+#' functions are also accepted. Default is `NULL`, which adds global p-values
+#' for all categorical and interaction terms.
+#' @param terms DEPRECATED.  Use `include=` argument instead.
 #' @param ... Additional arguments to be passed to [car::Anova]
 #' @author Daniel D. Sjoberg
 #' @family tbl_regression tools
@@ -58,31 +61,26 @@ add_global_p <- function(x, ...) {
 #' @section Example Output:
 #' \if{html}{\figure{tbl_lm_global_ex1.png}{options: width=50\%}}
 
-add_global_p.tbl_regression <- function(x, terms = NULL, keep = FALSE, ...) {
-
-  # fetching categorical variables from model
-  model_terms <- x %>%
-    pluck("table_body") %>%
-    select(c("var_type", "variable")) %>%
-    filter(!!parse_expr('var_type == "categorical"')) %>%
-    distinct() %>%
-    pull("variable")
-
-  # if not terms supplied, getting list of all categorical terms in model
-  if (is.null(terms)) terms <- model_terms
-
-  # if no terms are provided, stop and return x
-  if (length(terms) == 0) {
-    message("No terms were selected, and no global p-values added to table")
-    return(x)
+add_global_p.tbl_regression <- function(x,
+                                        include = x$table_body$variable[x$table_body$var_type %in% c("categorical", "interaction")],
+                                        keep = FALSE, terms = NULL, ...) {
+  # deprecated arguments -------------------------------------------------------
+  if (!is.null(terms)) {
+    lifecycle::deprecate_warn(
+      "1.2.5", "gtsummary::add_global_p.tbl_regression(terms = )",
+      "add_global_p.tbl_regression(include = )"
+    )
+    include <- terms
   }
 
-  # check that terms selected appear in model.
-  if (!all(terms %in% model_terms)) {
-    stop(glue(
-      "Terms selected are not categorical terms from model: ",
-      "{paste(terms[!(terms %in% model_terms)], collpase = ', ')}"
-    ))
+  # converting to charcter vector ----------------------------------------------
+  include <- var_input_to_string(data = vctr_2_tibble(unique(x$table_body$variable)),
+                                 select_input = !!rlang::enquo(include))
+
+  # if no terms are provided, stop and return x
+  if (length(include) == 0) {
+    message("No terms were selected, and no global p-values added to table")
+    return(x)
   }
 
   # calculating global pvalues
@@ -106,7 +104,7 @@ add_global_p.tbl_regression <- function(x, terms = NULL, keep = FALSE, ...) {
     car_Anova %>%
     as.data.frame() %>%
     tibble::rownames_to_column(var = "variable") %>%
-    filter(!!parse_expr("variable %in% terms")) %>%
+    filter(.data$variable %in% !!include) %>%
     select(c("variable", starts_with("Pr(>"))) %>% # selecting the pvalue column
     set_names(c("variable", "p.value_global")) %>%
     mutate(row_type = "label")
@@ -128,7 +126,7 @@ add_global_p.tbl_regression <- function(x, terms = NULL, keep = FALSE, ...) {
     x$table_body <-
       x$table_body %>%
       mutate(
-        p.value = if_else(.data$variable %in% terms & .data$row_type == "level",
+        p.value = if_else(.data$variable %in% !!include & .data$row_type == "level",
           NA_real_, .data$p.value
         )
       )
@@ -151,8 +149,7 @@ add_global_p.tbl_regression <- function(x, terms = NULL, keep = FALSE, ...) {
 #' @family tbl_uvregression tools
 #' @examples
 #' tbl_uv_global_ex2 <-
-#'   trial %>%
-#'   dplyr::select(response, trt, age, grade) %>%
+#'   trial[c("response", "trt", "age", "grade")] %>%
 #'   tbl_uvregression(
 #'     method = glm,
 #'     y = response,
@@ -166,26 +163,21 @@ add_global_p.tbl_regression <- function(x, terms = NULL, keep = FALSE, ...) {
 #' \if{html}{\figure{tbl_uv_global_ex2.png}{options: width=50\%}}
 #'
 add_global_p.tbl_uvregression <- function(x, ...) {
-
-  # converting the passed ... to a list, OR if nothing passed to NULL
-  if (length(list(...)) == 0) {
-    passed_dots <- NULL
-  } else {
-    passed_dots <- list(...)
-  }
+  # capturing dots in expression
+  dots <- rlang::enexprs(...)
 
   # calculating global pvalues
   global_p <-
     imap_dfr(
-      x$tbl_regression_list,
+      x$tbls,
       function(x, y) {
         tryCatch(
           {
             car_Anova <-
-              do.call(
-                car::Anova,
-                c(list(mod = x[["model_obj"]], type = "III"), passed_dots)
-              )
+              rlang::call2(
+                car::Anova, mod = x[["model_obj"]], type = "III", !!!dots
+              ) %>%
+              rlang::eval_tidy()
           },
           error = function(e) {
             usethis::ui_oops(paste0(
