@@ -1,19 +1,24 @@
+# magrittr ---------------------------------------------------------------------
 #' @export
 #' @importFrom magrittr %>%
 magrittr::`%>%`
 
+# tibble -----------------------------------------------------------------------
 #' @export
 #' @importFrom tibble as_tibble
 tibble::as_tibble
 
+# knitr ------------------------------------------------------------------------
 #' @export
 #' @importFrom knitr knit_print
 knitr::knit_print
 
+# dplyr ------------------------------------------------------------------------
 #' @importFrom dplyr vars
 #' @export
 dplyr::vars
 
+# tidyselect -------------------------------------------------------------------
 #' @importFrom tidyselect starts_with
 #' @export
 tidyselect::starts_with
@@ -30,18 +35,26 @@ tidyselect::contains
 #' @export
 tidyselect::matches
 
-#' @importFrom tidyselect one_of
+#' @importFrom tidyselect num_range
 #' @export
-tidyselect::one_of
+tidyselect::num_range
+
+#' @importFrom tidyselect all_of
+#' @export
+tidyselect::all_of
+
+#' @importFrom tidyselect any_of
+#' @export
+tidyselect::any_of
 
 #' @importFrom tidyselect everything
 #' @export
 tidyselect::everything
 
-#' @importFrom tidyselect num_range
-#' @export
-tidyselect::num_range
-
 #' @importFrom tidyselect last_col
 #' @export
 tidyselect::last_col
+
+#' @importFrom tidyselect one_of
+#' @export
+tidyselect::one_of
