@@ -29,24 +29,24 @@
 #'     tbls = list(t1, t2),
 #'     tab_spanner = c("**Tumor Response**", "**Time to Death**")
 #'   )
-#' \donttest{
+#'
 #' # Descriptive statistics alongside univariate regression, with no spanning header
 #' t3 <-
-#'   trial %>%
-#'   dplyr::select(age, grade, response) %>%
+#'   trial[c("age", "grade", "response")] %>%
 #'   tbl_summary(missing = "no") %>%
 #'   add_n()
 #' t4 <-
 #'   tbl_uvregression(
-#'     trial %>% dplyr::select(ttdeath, death, age, grade, response),
+#'     trial[c("ttdeath", "death", "age", "grade", "response")],
 #'     method = coxph,
 #'     y = Surv(ttdeath, death),
 #'     exponentiate = TRUE,
 #'     hide_n = TRUE
 #'   )
+#' \donttest{
 #' tbl_merge_ex2 <-
 #'   tbl_merge(tbls = list(t3, t4)) %>%
-#'   as_gt(exclude = "tab_spanner") %>%
+#'   as_gt(include = -tab_spanner) %>%
 #'   gt::cols_label(stat_0_1 = gt::md("**Summary Statistics**"))
 #' }
 #' @section Example Output:
@@ -66,13 +66,13 @@ tbl_merge <- function(tbls, tab_spanner = NULL) {
   }
 
   # class of tbls
-  if (!"list" %in% class(tbls)) {
+  if (!inherits(tbls, "list")) {
     stop("Expecting 'tbls' to be a list, e.g. 'tbls = list(tbl1, tbl2)'")
   }
 
   # checking all inputs are class tbl_regression, tbl_uvregression,
   # tbl_regression, tbl_summary, or tbl_stack
-  if (!map_chr(tbls, class) %in%
+  if (!map_chr(tbls, ~class(.x)[1]) %in%
     c("tbl_regression", "tbl_uvregression", "tbl_summary", "tbl_stack") %>% all()) {
     stop(paste(
       "All objects in 'tbls' must be class 'tbl_regression',",
@@ -99,19 +99,6 @@ tbl_merge <- function(tbls, tab_spanner = NULL) {
     ))
   }
 
-  # for tbl_summary, moving footnote above label column to the first stat_* column
-  tbls <- map_if(
-    tbls,
-    ~ class(.x) == "tbl_summary",
-    function(x) {
-      x$table_header$footnote[startsWith(x$table_header$column, "stat_")] <-
-        x$table_header$footnote[x$table_header$column == "label"][1]
-
-      x$table_header$footnote[x$table_header$column == "label"][1] <- list(NULL)
-      return(x)
-    }
-  )
-
   # merging tables -------------------------------------------------------------
   # nesting data by variable (one line per variable), and renaming columns with number suffix
   nested_table <- tbls %>%
@@ -179,8 +166,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL) {
       tbls,
       ~ pluck(.x, "table_header") %>%
         mutate(
-          column = paste0(.data$column, "_", .y),
-          fmt = stringr::str_replace(fmt, stringr::fixed("x$"), paste0("x$tbls[[", .y, "]]$"))
+          column = paste0(.data$column, "_", .y)
         )
     ) %>%
     # using the identifying columns from first passed object
@@ -205,9 +191,6 @@ tbl_merge <- function(tbls, tab_spanner = NULL) {
     table_body = table_body,
     table_header = table_header,
     tbls = tbls,
-    estimate_funs = map(tbl_inputs(tbls), pluck("estimate_fun")),
-    pvalue_funs = map(tbl_inputs(tbls), pluck("pvalue_fun")),
-    qvalue_funs = map(tbls, pluck("qvalue_fun")),
     call_list = list(tbl_merge = match.call()),
     gt_calls = eval(gt_tbl_merge),
     kable_calls = eval(kable_tbl_merge)
@@ -216,7 +199,7 @@ tbl_merge <- function(tbls, tab_spanner = NULL) {
   # writing additional gt and kable calls with data from table_header
   results <- update_calls_from_table_header(results)
 
-  class(results) <- "tbl_merge"
+  class(results) <- c("tbl_merge", "gtsummary")
   results
 }
 
@@ -243,11 +226,11 @@ gt_tbl_merge <- quote(list(
       tbls,
       function(x, y) {
         # returning NULL for non-regression objects
-        if (!class(x) %in% c("tbl_regression", "tbl_uvregression", "tbl_stack")) {
+        if (!inherits(x, c("tbl_regression", "tbl_uvregression", "tbl_stack"))) {
           return(NULL)
         }
-        if (class(x) == "tbl_stack" &&
-          !class(x$tbl_regression_list[[1]]) %in% c("tbl_regression", "tbl_uvregression")) {
+        if (inherits(x, "tbl_stack") &&
+          !inherits(x$tbls[[1]], c("tbl_regression", "tbl_uvregression"))) {
           return(NULL)
         }
         # making gt missing code for references
@@ -267,7 +250,7 @@ gt_tbl_merge <- quote(list(
   tab_style_text_indent = glue(
     "gt::tab_style(",
     "style = gt::cell_text(indent = gt::px(10), align = 'left'),",
-    "locations = gt::cells_data(",
+    "locations = gt::cells_body(",
     "columns = gt::vars(label),",
     "rows = row_type != 'label'",
     "))"
@@ -296,11 +279,11 @@ kable_tbl_merge <- quote(list(
       tbls,
       function(x, y) {
         # returning NULL for non-regression objects
-        if (!class(x) %in% c("tbl_regression", "tbl_uvregression", "tbl_stack")) {
+        if (!inherits(x, c("tbl_regression", "tbl_uvregression", "tbl_stack"))) {
           return(NULL)
         }
-        if (class(x) == "tbl_stack" &&
-          !class(x$tbl_regression_list[[1]]) %in% c("tbl_regression", "tbl_uvregression")) {
+        if (inherits(x, "tbl_stack") &&
+            !inherits(x$tbls[[1]], c("tbl_regression", "tbl_uvregression"))) {
           return(NULL)
         }
         # making mutate missing code for references
@@ -323,11 +306,11 @@ tbl_inputs <- function(tbl) {
   map(
     tbl,
     function(tbl) {
-      if (class(tbl) %in% c("tbl_regression", "tbl_stack", "tbl_summary")) {
+      if (inherits(tbl, c("tbl_regression", "tbl_uvregression", "tbl_stack"))) {
         return(pluck(tbl, "inputs"))
       }
-      if (class(tbl) == "tbl_uvregression") {
-        return(pluck(tbl, "tbl_regression_list", 1, "inputs"))
+      if (inherits(tbl, "tbl_uvregression")) {
+        return(pluck(tbl, "tbls", 1, "inputs"))
       }
     }
   )
