@@ -19,7 +19,7 @@
 #'   glm(response ~ trt, trial, family = binomial) %>%
 #'   tbl_regression(
 #'     exponentiate = TRUE,
-#'     label = list(vars(trt) ~ "Treatment (unadjusted)")
+#'     label = list(trt ~ "Treatment (unadjusted)")
 #'   )
 #'
 #' t2 <-
@@ -27,7 +27,7 @@
 #'   tbl_regression(
 #'     include = "trt",
 #'     exponentiate = TRUE,
-#'     label = list(vars(trt) ~ "Treatment (adjusted)")
+#'     label = list(trt ~ "Treatment (adjusted)")
 #'   )
 #'
 #' tbl_stack_ex1 <- tbl_stack(list(t1, t2))
@@ -38,7 +38,7 @@
 #'   coxph(Surv(ttdeath, death) ~ trt, trial) %>%
 #'   tbl_regression(
 #'     exponentiate = TRUE,
-#'     label = list(vars(trt) ~ "Treatment (unadjusted)")
+#'     label = list(trt ~ "Treatment (unadjusted)")
 #'   )
 #'
 #' t4 <-
@@ -46,7 +46,7 @@
 #'   tbl_regression(
 #'     include = "trt",
 #'     exponentiate = TRUE,
-#'     label = list(vars(trt) ~ "Treatment (adjusted)")
+#'     label = list(trt ~ "Treatment (adjusted)")
 #'   )
 #'
 #'
@@ -67,12 +67,12 @@
 tbl_stack <- function(tbls) {
   # input checks ---------------------------------------------------------------
   # class of tbls
-  if (!"list" %in% class(tbls)) {
+  if (!inherits(tbls, "list")) {
     stop("Expecting 'tbls' to be a list, e.g. 'tbls = list(tbl1, tbl2)'")
   }
 
   # checking all inputs are class tbl_uvregression, tbl_regression, tbl_summary, or tbl_merge
-  if (!map_chr(tbls, class) %in% c(
+  if (!map_chr(tbls, ~class(.x)[1]) %in% c(
     "tbl_regression", "tbl_uvregression",
     "tbl_summary", "tbl_merge"
   ) %>% any()) {
@@ -81,41 +81,41 @@ tbl_stack <- function(tbls) {
   }
 
   # printing message if stacking tbl_summary and regression object
-  if ("tbl_summary" %in% map_chr(tbls, class) &&
-    any(c("tbl_regression", "tbl_uvregression") %in% map_chr(tbls, class))) {
+  if ("tbl_summary" %in% map_chr(tbls, ~class(.x)[1]) &&
+    any(c("tbl_regression", "tbl_uvregression") %in% map_chr(tbls, ~class(.x)[1]))) {
     message(paste(
       "You are stacking a gtsummary regression table and a summary table,",
       "which is not recommended. Consider revising the format of your table."
     ))
   }
 
-  # at least two objects must be passed
-  tbls_length <- length(tbls)
-  if (tbls_length < 2L) stop("Supply 2 or more gtsummary regression objects to 'tbls ='")
-
   # checking if there are multiple input types
-  if (map_chr(tbls, class) %>% unique() %>% length() > 1) {
+  if (map_chr(tbls, ~class(.x)[1]) %>% unique() %>% length() > 1) {
     message("Multiple gtsummary object classes detected. Displayed results default to first input class type.")
   }
 
-  # stacking tables ------------------------------------------------------------
-  results <- tbls[[1]][names(tbls[[1]]) %>% intersect(c(
-    "inputs", "gt_calls", "kable_calls", "estimate_funs",
-    "pvalue_funs", "qvalue_funs",
-    "pvalue_fun", "qvalue_fun",
-    "table_header", "tbls"
-  ))]
+  # will return call, and all arguments passed to tbl_stack
+  func_inputs <- as.list(environment())
 
+  # stacking tables ------------------------------------------------------------
+  # the table_body and call_list will be updated with the tbl_stack values
+  results <- tbls[[1]][c("gt_calls", "kable_calls")]
   results$table_body <-
-    map_dfr(
-      tbls,
-      ~ pluck(.x, "table_body")
-    )
+    map_dfr(tbls, ~pluck(.x, "table_body"))
+
+  results$table_header <-
+    map_dfr(tbls, ~pluck(.x, "table_header")) %>%
+    group_by(.data$column) %>%
+    filter(dplyr::row_number() == 1) %>%
+    ungroup()
+
+  # writing additional gt and kable calls with data from table_header
+  results <- update_calls_from_table_header(results)
 
   # returning results ----------------------------------------------------------
   results$call_list <- list(tbl_stack = match.call())
-  results$tbl_regression_list <- tbls
+  results$tbls <- tbls
 
-  class(results) <- "tbl_stack"
-  return(results)
+  class(results) <- c("tbl_stack", "gtsummary")
+  results
 }
