@@ -19,3 +19,14 @@ test_that("assign_dichotomous_value_one for yes/no factors", {
     "yes"
   )
 })
+
+test_that("input checks", {
+  expect_error(
+    assign_dichotomous_value(
+      data = trial, variable = "stage",
+      summary_type = "dichotomous",
+      class = "factor", value = NULL
+    ),
+    "'stage' is dichotomous, but I was unable to determine the level.*"
+  )
+})
