@@ -125,3 +125,21 @@ test_that("All labels print with cubic splines", {
     0
   )
 })
+
+
+test_that("Testing lme4 results", {
+  mod_glmer <- glmer(am ~ hp + factor(cyl) + (1 | gear), mtcars, family = binomial)
+
+  # tbl_regerssion runs without error
+  expect_error(
+    tbl_lme4 <- tbl_regression(mod_glmer, exponentiate = TRUE,
+                               conf.level = 0.90),
+    NA
+  )
+
+  # coefs are exponentiated properly
+  expect_equivalent(
+    coef(mod_glmer)[[1]] %>% {.[1, 2:ncol(.)]} %>% map_dbl(exp),
+    tbl_lme4$table_body %>% pull(estimate) %>% discard(is.na)
+  )
+})
