@@ -53,6 +53,26 @@ test_that("tbl_summary value argument works properly", {
   )
 })
 
+test_that("tbl_summary works in character inputs for `by=`", {
+  my_by_variable <- "trt"
+
+  expect_error(
+    tbl_summary(trial, by = my_by_variable),
+    NA
+  )
+  expect_error(
+    tbl_summary(trial, by = "trt"),
+    NA
+  )
+  expect_error(
+    purrr::map(
+      c("trt", "grade", "stage"),
+      ~tbl_summary(trial, by = .x)
+    ),
+    NA
+  )
+})
+
 
 test_that("tbl_summary returns errors with bad inputs", {
   expect_error(
@@ -99,6 +119,10 @@ test_that("tbl_summary returns errors with bad inputs", {
     tbl_summary(trial, sort = list("grade" ~ "frequ55555ency")),
     "*"
   )
+  expect_error(
+    tbl_summary(trial, by = c("trt", "grade")),
+    "*"
+  )
 })
 
 
@@ -118,11 +142,11 @@ test_that("tbl_summary-testing tidyselect parsing", {
           c("grade", "stage") ~ "{n}"
         ),
         label = list(
-          age = "Patient Age", vars(stage) ~ "Patient Stage",
+          age ~ "Patient Age", vars(stage) ~ "Patient Stage",
           vars(`bad grade`) ~ "Crazy Grade"
         ),
-        digits = list(vars(age) ~ c(2, 3), marker = c(2, 3)),
-        value = list(vars(`bad grade`) ~ "III", "stage" ~ "T1"),
+        digits = list(vars(age) ~ c(2, 3), marker ~ c(2, 3)),
+        value = list(`bad grade` = "III", "stage" = "T1"),
         missing = "no"
       ),
     NA
@@ -231,3 +255,113 @@ test_that("tbl_summary-order of output columns", {
     paste0("stat_", 1:3)
   )
 })
+
+test_that("tbl_summary-all_categorical() use with `type=`", {
+  # no variables should be dichotomous
+  expect_true(
+    !"dichotomous" %in%
+      (tbl_summary(trial, type = all_dichotomous() ~ "categorical") %>%
+         purrr::pluck("meta_data") %>%
+         dplyr::pull(summary_type))
+  )
+})
+
+
+test_that("tbl_summary-difftime does not cause error", {
+
+  expect_error(
+    dplyr::storms %>%
+      dplyr::mutate(
+        date = ISOdate(year, month, day),
+        date_diff = difftime(dplyr::lag(date, 5), date, units = "days")
+      ) %>%
+      tbl_summary(),
+    NA
+  )
+})
+
+
+test_that("tbl_summary-all missing data does not cause error", {
+  df_missing <-
+    tibble(
+      my_by_var = c(1,1,2,2),
+      fct = rep(NA, 4) %>% factor(levels = c("lion", "tiger", "bear")),
+      lgl = NA,
+      chr = NA_character_,
+      int = NA_integer_,
+      dbl = NA_real_
+    )
+
+  expect_error(
+    all_missing_no_by <- tbl_summary(df_missing %>% dplyr::select(-my_by_var)),
+    NA
+  )
+
+  expect_error(
+    all_missing_by <- tbl_summary(df_missing, by = my_by_var),
+    NA
+  )
+
+  # making categorical, variables that cannot be summarized as categorical
+  expect_error(
+    tbl_summary(df_missing, by = my_by_var, type = vars(int, dbl) ~ "categorical"),
+    NA
+  )
+
+  expect_equal(
+    all_missing_no_by$table_body %>%
+      filter(variable == "fct", row_type == "level") %>%
+      pull(stat_0),
+    c("0 (NA%)", "0 (NA%)", "0 (NA%)")
+  )
+
+  expect_equal(
+    all_missing_no_by$table_body %>%
+      filter(variable %in% c("lgl", "chr"), row_type == "label") %>%
+      pull(stat_0),
+    c("0 (NA%)", "0 (NA%)")
+  )
+
+  expect_equal(
+    all_missing_no_by$table_body %>%
+      filter(variable %in% c("int", "dbl"), row_type == "label") %>%
+      pull(stat_0),
+    c("NA (NA, NA)", "NA (NA, NA)")
+  )
+
+  expect_equal(
+    all_missing_by$table_body %>%
+      filter(variable == "fct", row_type == "level") %>%
+      select(starts_with("stat_")),
+    tibble(stat_1 = c("0 (NA%)", "0 (NA%)", "0 (NA%)"), stat_2 = stat_1)
+  )
+
+  expect_equal(
+    all_missing_by$table_body %>%
+      filter(variable %in% c("lgl", "chr"), row_type == "label") %>%
+      select(starts_with("stat_")),
+    tibble(stat_1 = c("0 (NA%)", "0 (NA%)"), stat_2 = stat_1)
+  )
+
+  expect_equal(
+    all_missing_by$table_body %>%
+      filter(variable %in% c("int", "dbl"), row_type == "label") %>%
+      select(starts_with("stat_")),
+    tibble(stat_1 = c("NA (NA, NA)", "NA (NA, NA)"), stat_2 = stat_1)
+  )
+
+  # unobserved factor level
+  expect_error(
+    missing_fct_by <-
+      trial %>%
+      mutate(response2 = factor(response) %>% forcats::fct_explicit_na()) %>%
+      filter(!is.na(response)) %>%
+      tbl_summary(by = response2),
+    NA
+  )
+
+  expect_equal(
+    missing_fct_by$table_body %>% select(starts_with("stat_")) %>% names(),
+    c("stat_1", "stat_2", "stat_3")
+  )
+})
