@@ -9,10 +9,6 @@ test_that("input check", {
     tbl_summary(trial, type = list("cont555inuous")),
     "*"
   )
-  expect_error(
-    tbl_summary(trial, type = all_continuous() ~ "continuous"),
-    "*"
-  )
   expect_error(
     tbl_summary(trial, value = list("Drug")),
     "*"
@@ -45,4 +41,8 @@ test_that("input check", {
     tbl_summary(trial, sort = TRUE),
     "*"
   )
+  expect_error(
+    tbl_summary(trial %>% select(-everything())),
+    "*"
+  )
 })
